/**
 * --------------------------------------------------------------------------------------------------------------------
 * <copyright company="Aspose Pty Ltd" file="SignTextOptionsData.java">
 *   Copyright (c) 2003-2018 Aspose Pty Ltd
 * </copyright>
 * <summary>
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------------------------------------------
 */

package com.groupdocs.cloud.signature.model;

import java.util.Objects;
import com.google.gson.TypeAdapter;
import com.google.gson.annotations.JsonAdapter;
import com.google.gson.annotations.SerializedName;
import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import com.groupdocs.cloud.signature.model.BrushData;
import com.groupdocs.cloud.signature.model.Color;
import com.groupdocs.cloud.signature.model.PaddingData;
import com.groupdocs.cloud.signature.model.PagesSetupData;
import com.groupdocs.cloud.signature.model.SignOptionsData;
import com.groupdocs.cloud.signature.model.SignatureFontData;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.IOException;

/**
 * Base container class for signature options data
 */
@ApiModel(description = "Base container class for signature options data")
public class SignTextOptionsData extends SignOptionsData {
  @SerializedName("left")
  private Integer left = null;

  @SerializedName("top")
  private Integer top = null;

  @SerializedName("width")
  private Integer width = null;

  @SerializedName("height")
  private Integer height = null;

  /**
   * Measure type (pixels or percent) for Left and Top properties.
   */
  @JsonAdapter(LocationMeasureTypeEnum.Adapter.class)
  public enum LocationMeasureTypeEnum {
    PIXELS("Pixels"),
    
    PERCENTS("Percents"),
    
    MILLIMETERS("Millimeters");

    private String value;

    LocationMeasureTypeEnum(String value) {
      this.value = value;
    }

    public String getValue() {
      return value;
    }

    @Override
    public String toString() {
      return String.valueOf(value);
    }

    public static LocationMeasureTypeEnum fromValue(String text) {
      for (LocationMeasureTypeEnum b : LocationMeasureTypeEnum.values()) {
        if (String.valueOf(b.value).equals(text)) {
          return b;
        }
      }
      return null;
    }

    public static class Adapter extends TypeAdapter<LocationMeasureTypeEnum> {
      @Override
      public void write(final JsonWriter jsonWriter, final LocationMeasureTypeEnum enumeration) throws IOException {
        jsonWriter.value(enumeration.getValue());
      }

      @Override
      public LocationMeasureTypeEnum read(final JsonReader jsonReader) throws IOException {
        String value = jsonReader.nextString();
        return LocationMeasureTypeEnum.fromValue(String.valueOf(value));
      }
    }
  }

  @SerializedName("locationMeasureType")
  private LocationMeasureTypeEnum locationMeasureType = null;

  /**
   * Measure type (pixels or percent) for Width and Height properties.
   */
  @JsonAdapter(SizeMeasureTypeEnum.Adapter.class)
  public enum SizeMeasureTypeEnum {
    PIXELS("Pixels"),
    
    PERCENTS("Percents"),
    
    MILLIMETERS("Millimeters");

    private String value;

    SizeMeasureTypeEnum(String value) {
      this.value = value;
    }

    public String getValue() {
      return value;
    }

    @Override
    public String toString() {
      return String.valueOf(value);
    }

    public static SizeMeasureTypeEnum fromValue(String text) {
      for (SizeMeasureTypeEnum b : SizeMeasureTypeEnum.values()) {
        if (String.valueOf(b.value).equals(text)) {
          return b;
        }
      }
      return null;
    }

    public static class Adapter extends TypeAdapter<SizeMeasureTypeEnum> {
      @Override
      public void write(final JsonWriter jsonWriter, final SizeMeasureTypeEnum enumeration) throws IOException {
        jsonWriter.value(enumeration.getValue());
      }

      @Override
      public SizeMeasureTypeEnum read(final JsonReader jsonReader) throws IOException {
        String value = jsonReader.nextString();
        return SizeMeasureTypeEnum.fromValue(String.valueOf(value));
      }
    }
  }

  @SerializedName("sizeMeasureType")
  private SizeMeasureTypeEnum sizeMeasureType = null;

  /**
   * Stretch mode on Document Page
   */
  @JsonAdapter(StretchEnum.Adapter.class)
  public enum StretchEnum {
    NONE("None"),
    
    PAGEWIDTH("PageWidth"),
    
    PAGEHEIGHT("PageHeight"),
    
    PAGEAREA("PageArea");

    private String value;

    StretchEnum(String value) {
      this.value = value;
    }

    public String getValue() {
      return value;
    }

    @Override
    public String toString() {
      return String.valueOf(value);
    }

    public static StretchEnum fromValue(String text) {
      for (StretchEnum b : StretchEnum.values()) {
        if (String.valueOf(b.value).equals(text)) {
          return b;
        }
      }
      return null;
    }

    public static class Adapter extends TypeAdapter<StretchEnum> {
      @Override
      public void write(final JsonWriter jsonWriter, final StretchEnum enumeration) throws IOException {
        jsonWriter.value(enumeration.getValue());
      }

      @Override
      public StretchEnum read(final JsonReader jsonReader) throws IOException {
        String value = jsonReader.nextString();
        return StretchEnum.fromValue(String.valueOf(value));
      }
    }
  }

  @SerializedName("stretch")
  private StretchEnum stretch = null;

  @SerializedName("rotationAngle")
  private Integer rotationAngle = null;

  /**
   * Horizontal alignment of signature on document page.
   */
  @JsonAdapter(HorizontalAlignmentEnum.Adapter.class)
  public enum HorizontalAlignmentEnum {
    DEFAULT("Default"),
    
    NONE("None"),
    
    LEFT("Left"),
    
    CENTER("Center"),
    
    RIGHT("Right");

    private String value;

    HorizontalAlignmentEnum(String value) {
      this.value = value;
    }

    public String getValue() {
      return value;
    }

    @Override
    public String toString() {
      return String.valueOf(value);
    }

    public static HorizontalAlignmentEnum fromValue(String text) {
      for (HorizontalAlignmentEnum b : HorizontalAlignmentEnum.values()) {
        if (String.valueOf(b.value).equals(text)) {
          return b;
        }
      }
      return null;
    }

    public static class Adapter extends TypeAdapter<HorizontalAlignmentEnum> {
      @Override
      public void write(final JsonWriter jsonWriter, final HorizontalAlignmentEnum enumeration) throws IOException {
        jsonWriter.value(enumeration.getValue());
      }

      @Override
      public HorizontalAlignmentEnum read(final JsonReader jsonReader) throws IOException {
        String value = jsonReader.nextString();
        return HorizontalAlignmentEnum.fromValue(String.valueOf(value));
      }
    }
  }

  @SerializedName("horizontalAlignment")
  private HorizontalAlignmentEnum horizontalAlignment = null;

  /**
   * Vertical alignment of signature on document page.
   */
  @JsonAdapter(VerticalAlignmentEnum.Adapter.class)
  public enum VerticalAlignmentEnum {
    DEFAULT("Default"),
    
    NONE("None"),
    
    TOP("Top"),
    
    CENTER("Center"),
    
    BOTTOM("Bottom");

    private String value;

    VerticalAlignmentEnum(String value) {
      this.value = value;
    }

    public String getValue() {
      return value;
    }

    @Override
    public String toString() {
      return String.valueOf(value);
    }

    public static VerticalAlignmentEnum fromValue(String text) {
      for (VerticalAlignmentEnum b : VerticalAlignmentEnum.values()) {
        if (String.valueOf(b.value).equals(text)) {
          return b;
        }
      }
      return null;
    }

    public static class Adapter extends TypeAdapter<VerticalAlignmentEnum> {
      @Override
      public void write(final JsonWriter jsonWriter, final VerticalAlignmentEnum enumeration) throws IOException {
        jsonWriter.value(enumeration.getValue());
      }

      @Override
      public VerticalAlignmentEnum read(final JsonReader jsonReader) throws IOException {
        String value = jsonReader.nextString();
        return VerticalAlignmentEnum.fromValue(String.valueOf(value));
      }
    }
  }

  @SerializedName("verticalAlignment")
  private VerticalAlignmentEnum verticalAlignment = null;

  @SerializedName("margin")
  private PaddingData margin = null;

  /**
   * Gets or sets the measure type (pixels or percent) for Margin.
   */
  @JsonAdapter(MarginMeasureTypeEnum.Adapter.class)
  public enum MarginMeasureTypeEnum {
    PIXELS("Pixels"),
    
    PERCENTS("Percents"),
    
    MILLIMETERS("Millimeters");

    private String value;

    MarginMeasureTypeEnum(String value) {
      this.value = value;
    }

    public String getValue() {
      return value;
    }

    @Override
    public String toString() {
      return String.valueOf(value);
    }

    public static MarginMeasureTypeEnum fromValue(String text) {
      for (MarginMeasureTypeEnum b : MarginMeasureTypeEnum.values()) {
        if (String.valueOf(b.value).equals(text)) {
          return b;
        }
      }
      return null;
    }

    public static class Adapter extends TypeAdapter<MarginMeasureTypeEnum> {
      @Override
      public void write(final JsonWriter jsonWriter, final MarginMeasureTypeEnum enumeration) throws IOException {
        jsonWriter.value(enumeration.getValue());
      }

      @Override
      public MarginMeasureTypeEnum read(final JsonReader jsonReader) throws IOException {
        String value = jsonReader.nextString();
        return MarginMeasureTypeEnum.fromValue(String.valueOf(value));
      }
    }
  }

  @SerializedName("marginMeasureType")
  private MarginMeasureTypeEnum marginMeasureType = null;

  @SerializedName("text")
  private String text = null;

  @SerializedName("signAllPages")
  private Boolean signAllPages = null;

  @SerializedName("font")
  private SignatureFontData font = null;

  @SerializedName("foreColor")
  private Color foreColor = null;

  @SerializedName("borderColor")
  private Color borderColor = null;

  @SerializedName("backgroundColor")
  private Color backgroundColor = null;

  @SerializedName("backgroundBrush")
  private BrushData backgroundBrush = null;

  public SignTextOptionsData left(Integer left) {
    this.left = left;
    return this;
  }

   /**
   * Left X position of Signature on Document Page in Measure values (pixels or percent see  LocationMeasureType property)
   * @return left
  **/
  @ApiModelProperty(value = "Left X position of Signature on Document Page in Measure values (pixels or percent see  LocationMeasureType property)")
  public Integer getLeft() {
    return left;
  }

  public void setLeft(Integer left) {
    this.left = left;
  }

  public SignTextOptionsData top(Integer top) {
    this.top = top;
    return this;
  }

   /**
   * Top Y Position of Signature on Document Page in Measure values (pixels or percent see  LocationMeasureType property)
   * @return top
  **/
  @ApiModelProperty(value = "Top Y Position of Signature on Document Page in Measure values (pixels or percent see  LocationMeasureType property)")
  public Integer getTop() {
    return top;
  }

  public void setTop(Integer top) {
    this.top = top;
  }

  public SignTextOptionsData width(Integer width) {
    this.width = width;
    return this;
  }

   /**
   * Width of Signature area on Document Page in Measure values (pixels or percent see  SizeMeasureType property)
   * @return width
  **/
  @ApiModelProperty(value = "Width of Signature area on Document Page in Measure values (pixels or percent see  SizeMeasureType property)")
  public Integer getWidth() {
    return width;
  }

  public void setWidth(Integer width) {
    this.width = width;
  }

  public SignTextOptionsData height(Integer height) {
    this.height = height;
    return this;
  }

   /**
   * Height of Signature are on Document Page in Measure values (pixels or percent see  SizeMeasureType property)
   * @return height
  **/
  @ApiModelProperty(value = "Height of Signature are on Document Page in Measure values (pixels or percent see  SizeMeasureType property)")
  public Integer getHeight() {
    return height;
  }

  public void setHeight(Integer height) {
    this.height = height;
  }

  public SignTextOptionsData locationMeasureType(LocationMeasureTypeEnum locationMeasureType) {
    this.locationMeasureType = locationMeasureType;
    return this;
  }

   /**
   * Measure type (pixels or percent) for Left and Top properties.
   * @return locationMeasureType
  **/
  @ApiModelProperty(value = "Measure type (pixels or percent) for Left and Top properties.")
  public LocationMeasureTypeEnum getLocationMeasureType() {
    return locationMeasureType;
  }

  public void setLocationMeasureType(LocationMeasureTypeEnum locationMeasureType) {
    this.locationMeasureType = locationMeasureType;
  }

  public SignTextOptionsData sizeMeasureType(SizeMeasureTypeEnum sizeMeasureType) {
    this.sizeMeasureType = sizeMeasureType;
    return this;
  }

   /**
   * Measure type (pixels or percent) for Width and Height properties.
   * @return sizeMeasureType
  **/
  @ApiModelProperty(value = "Measure type (pixels or percent) for Width and Height properties.")
  public SizeMeasureTypeEnum getSizeMeasureType() {
    return sizeMeasureType;
  }

  public void setSizeMeasureType(SizeMeasureTypeEnum sizeMeasureType) {
    this.sizeMeasureType = sizeMeasureType;
  }

  public SignTextOptionsData stretch(StretchEnum stretch) {
    this.stretch = stretch;
    return this;
  }

   /**
   * Stretch mode on Document Page
   * @return stretch
  **/
  @ApiModelProperty(value = "Stretch mode on Document Page")
  public StretchEnum getStretch() {
    return stretch;
  }

  public void setStretch(StretchEnum stretch) {
    this.stretch = stretch;
  }

  public SignTextOptionsData rotationAngle(Integer rotationAngle) {
    this.rotationAngle = rotationAngle;
    return this;
  }

   /**
   * Rotation angle of signature on document page (clockwise).
   * @return rotationAngle
  **/
  @ApiModelProperty(value = "Rotation angle of signature on document page (clockwise).")
  public Integer getRotationAngle() {
    return rotationAngle;
  }

  public void setRotationAngle(Integer rotationAngle) {
    this.rotationAngle = rotationAngle;
  }

  public SignTextOptionsData horizontalAlignment(HorizontalAlignmentEnum horizontalAlignment) {
    this.horizontalAlignment = horizontalAlignment;
    return this;
  }

   /**
   * Horizontal alignment of signature on document page.
   * @return horizontalAlignment
  **/
  @ApiModelProperty(value = "Horizontal alignment of signature on document page.")
  public HorizontalAlignmentEnum getHorizontalAlignment() {
    return horizontalAlignment;
  }

  public void setHorizontalAlignment(HorizontalAlignmentEnum horizontalAlignment) {
    this.horizontalAlignment = horizontalAlignment;
  }

  public SignTextOptionsData verticalAlignment(VerticalAlignmentEnum verticalAlignment) {
    this.verticalAlignment = verticalAlignment;
    return this;
  }

   /**
   * Vertical alignment of signature on document page.
   * @return verticalAlignment
  **/
  @ApiModelProperty(value = "Vertical alignment of signature on document page.")
  public VerticalAlignmentEnum getVerticalAlignment() {
    return verticalAlignment;
  }

  public void setVerticalAlignment(VerticalAlignmentEnum verticalAlignment) {
    this.verticalAlignment = verticalAlignment;
  }

  public SignTextOptionsData margin(PaddingData margin) {
    this.margin = margin;
    return this;
  }

   /**
   * Gets or sets the space between Sign and Document edges. (works ONLY if horizontal or vertical alignment are specified).
   * @return margin
  **/
  @ApiModelProperty(value = "Gets or sets the space between Sign and Document edges. (works ONLY if horizontal or vertical alignment are specified).")
  public PaddingData getMargin() {
    return margin;
  }

  public void setMargin(PaddingData margin) {
    this.margin = margin;
  }

  public SignTextOptionsData marginMeasureType(MarginMeasureTypeEnum marginMeasureType) {
    this.marginMeasureType = marginMeasureType;
    return this;
  }

   /**
   * Gets or sets the measure type (pixels or percent) for Margin.
   * @return marginMeasureType
  **/
  @ApiModelProperty(value = "Gets or sets the measure type (pixels or percent) for Margin.")
  public MarginMeasureTypeEnum getMarginMeasureType() {
    return marginMeasureType;
  }

  public void setMarginMeasureType(MarginMeasureTypeEnum marginMeasureType) {
    this.marginMeasureType = marginMeasureType;
  }

  public SignTextOptionsData text(String text) {
    this.text = text;
    return this;
  }

   /**
   * Text of signature
   * @return text
  **/
  @ApiModelProperty(value = "Text of signature")
  public String getText() {
    return text;
  }

  public void setText(String text) {
    this.text = text;
  }

  public SignTextOptionsData signAllPages(Boolean signAllPages) {
    this.signAllPages = signAllPages;
    return this;
  }

   /**
   * Put signature on all document pages.
   * @return signAllPages
  **/
  @ApiModelProperty(value = "Put signature on all document pages.")
  public Boolean isSignAllPages() {
    return signAllPages;
  }

  public void setSignAllPages(Boolean signAllPages) {
    this.signAllPages = signAllPages;
  }

  public SignTextOptionsData font(SignatureFontData font) {
    this.font = font;
    return this;
  }

   /**
   * Gets or sets the font of signature.
   * @return font
  **/
  @ApiModelProperty(value = "Gets or sets the font of signature.")
  public SignatureFontData getFont() {
    return font;
  }

  public void setFont(SignatureFontData font) {
    this.font = font;
  }

  public SignTextOptionsData foreColor(Color foreColor) {
    this.foreColor = foreColor;
    return this;
  }

   /**
   * Gets or sets the fore color of signature.
   * @return foreColor
  **/
  @ApiModelProperty(value = "Gets or sets the fore color of signature.")
  public Color getForeColor() {
    return foreColor;
  }

  public void setForeColor(Color foreColor) {
    this.foreColor = foreColor;
  }

  public SignTextOptionsData borderColor(Color borderColor) {
    this.borderColor = borderColor;
    return this;
  }

   /**
   * Gets or sets the border color of signature.
   * @return borderColor
  **/
  @ApiModelProperty(value = "Gets or sets the border color of signature.")
  public Color getBorderColor() {
    return borderColor;
  }

  public void setBorderColor(Color borderColor) {
    this.borderColor = borderColor;
  }

  public SignTextOptionsData backgroundColor(Color backgroundColor) {
    this.backgroundColor = backgroundColor;
    return this;
  }

   /**
   * Gets or sets the background color of signature.
   * @return backgroundColor
  **/
  @ApiModelProperty(value = "Gets or sets the background color of signature.")
  public Color getBackgroundColor() {
    return backgroundColor;
  }

  public void setBackgroundColor(Color backgroundColor) {
    this.backgroundColor = backgroundColor;
  }

  public SignTextOptionsData backgroundBrush(BrushData backgroundBrush) {
    this.backgroundBrush = backgroundBrush;
    return this;
  }

   /**
   * Gets or sets the signature background brush. Value by default is null.  If this property has a value it will be used instead BackgroundBrush property.
   * @return backgroundBrush
  **/
  @ApiModelProperty(value = "Gets or sets the signature background brush. Value by default is null.  If this property has a value it will be used instead BackgroundBrush property.")
  public BrushData getBackgroundBrush() {
    return backgroundBrush;
  }

  public void setBackgroundBrush(BrushData backgroundBrush) {
    this.backgroundBrush = backgroundBrush;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SignTextOptionsData signTextOptionsData = (SignTextOptionsData) o;
    return Objects.equals(this.left, signTextOptionsData.left) &&
        Objects.equals(this.top, signTextOptionsData.top) &&
        Objects.equals(this.width, signTextOptionsData.width) &&
        Objects.equals(this.height, signTextOptionsData.height) &&
        Objects.equals(this.locationMeasureType, signTextOptionsData.locationMeasureType) &&
        Objects.equals(this.sizeMeasureType, signTextOptionsData.sizeMeasureType) &&
        Objects.equals(this.stretch, signTextOptionsData.stretch) &&
        Objects.equals(this.rotationAngle, signTextOptionsData.rotationAngle) &&
        Objects.equals(this.horizontalAlignment, signTextOptionsData.horizontalAlignment) &&
        Objects.equals(this.verticalAlignment, signTextOptionsData.verticalAlignment) &&
        Objects.equals(this.margin, signTextOptionsData.margin) &&
        Objects.equals(this.marginMeasureType, signTextOptionsData.marginMeasureType) &&
        Objects.equals(this.text, signTextOptionsData.text) &&
        Objects.equals(this.signAllPages, signTextOptionsData.signAllPages) &&
        Objects.equals(this.font, signTextOptionsData.font) &&
        Objects.equals(this.foreColor, signTextOptionsData.foreColor) &&
        Objects.equals(this.borderColor, signTextOptionsData.borderColor) &&
        Objects.equals(this.backgroundColor, signTextOptionsData.backgroundColor) &&
        Objects.equals(this.backgroundBrush, signTextOptionsData.backgroundBrush) &&
        super.equals(o);
  }

  @Override
  public int hashCode() {
    return Objects.hash(left, top, width, height, locationMeasureType, sizeMeasureType, stretch, rotationAngle, horizontalAlignment, verticalAlignment, margin, marginMeasureType, text, signAllPages, font, foreColor, borderColor, backgroundColor, backgroundBrush, super.hashCode());
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SignTextOptionsData {\n");
    sb.append("    ").append(toIndentedString(super.toString())).append("\n");
    sb.append("    left: ").append(toIndentedString(left)).append("\n");
    sb.append("    top: ").append(toIndentedString(top)).append("\n");
    sb.append("    width: ").append(toIndentedString(width)).append("\n");
    sb.append("    height: ").append(toIndentedString(height)).append("\n");
    sb.append("    locationMeasureType: ").append(toIndentedString(locationMeasureType)).append("\n");
    sb.append("    sizeMeasureType: ").append(toIndentedString(sizeMeasureType)).append("\n");
    sb.append("    stretch: ").append(toIndentedString(stretch)).append("\n");
    sb.append("    rotationAngle: ").append(toIndentedString(rotationAngle)).append("\n");
    sb.append("    horizontalAlignment: ").append(toIndentedString(horizontalAlignment)).append("\n");
    sb.append("    verticalAlignment: ").append(toIndentedString(verticalAlignment)).append("\n");
    sb.append("    margin: ").append(toIndentedString(margin)).append("\n");
    sb.append("    marginMeasureType: ").append(toIndentedString(marginMeasureType)).append("\n");
    sb.append("    text: ").append(toIndentedString(text)).append("\n");
    sb.append("    signAllPages: ").append(toIndentedString(signAllPages)).append("\n");
    sb.append("    font: ").append(toIndentedString(font)).append("\n");
    sb.append("    foreColor: ").append(toIndentedString(foreColor)).append("\n");
    sb.append("    borderColor: ").append(toIndentedString(borderColor)).append("\n");
    sb.append("    backgroundColor: ").append(toIndentedString(backgroundColor)).append("\n");
    sb.append("    backgroundBrush: ").append(toIndentedString(backgroundBrush)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

